@@ -1,6 +1,11 @@
 def test1():
     print("test1 fun")
 
+
+def cli():
+    print("test1 cli fun")
+
+
 if __name__ == "__main__":
     test1()
     print("test1 main")
\ No newline at end of file
